Module api

Module api 

Safer wrapper around stable-diffusion.cpp bindings

Structs

BackendDeviceIter
An iterator over the variants of BackendDevice
Config
Config struct common to all diffusion methods
ConfigBuilder
Builder for Config.
DbCacheParams
Parameters for Db Cache
DbCacheParamsBuilder
Builder for DbCacheParams.
EasyCacheParams
Parameters for Easy Cache
EasyCacheParamsBuilder
Builder for EasyCacheParams.
HiresParams
Hires parameters
HiresParamsBuilder
Builder for HiresParams.
LoraSpec
Specify the instructions for a Lora model
ModelConfig
Config struct for a specific diffusion model
ModelConfigBuilder
Builder for ModelConfig.
ModuleIter
An iterator over the variants of Module
Progress
Progress message returned fron gen_img_with_progress
SpectrumCacheParams
Parameters for Spectrum Caching
SpectrumCacheParamsBuilder
Builder for SpectrumCacheParams.
UCacheParams
Parameters for UCache
UCacheParamsBuilder
Builder for UCacheParams.

Enums

BackendDevice
Backend devices
ClipSkip
Ignore the lower X layers of CLIP network
ConfigBuilderError
Error type for ConfigBuilder
DbCacheParamsBuilderError
Error type for DbCacheParamsBuilder
DiffusionError
Error that can occurs while forwarding models
EasyCacheParamsBuilderError
Error type for EasyCacheParamsBuilder
HiresParamsBuilderError
Error type for HiresParamsBuilder
LoraModeType
Lora mode
Module
Module that can be bound to a specific BackendDevice
Prediction
Prediction override
PreviewType
Preview mode
RngFunction
Specify the range function
SampleMethod
Sampling methods
Scheduler
Denoiser sigma schedule
ScmPolicy
Steps Computation Mask Policy controls when to cache steps
SpectrumCacheParamsBuilderError
Error type for SpectrumCacheParamsBuilder
UCacheParamsBuilderError
Error type for UCacheParamsBuilder
Upscaler
Hires mode
VaeFormat
VAE latent format
WeightType
Weight type

Functions

gen_img
Generate an image
gen_img_with_progress
Generate an image and receive update via queue