pub struct HiresParamsBuilder { /* private fields */ }Expand description
Builder for HiresParams.
Implementations
Sourceimpl HiresParamsBuilder
impl HiresParamsBuilder
Sourcepub fn width(&mut self, value: i32) -> &mut Self
pub fn width(&mut self, value: i32) -> &mut Self
highres fix target width, 0 to use scale (default: 0)
Sourcepub fn height(&mut self, value: i32) -> &mut Self
pub fn height(&mut self, value: i32) -> &mut Self
highres fix target height, 0 to use scale (default: 0)
Sourcepub fn steps(&mut self, value: i32) -> &mut Self
pub fn steps(&mut self, value: i32) -> &mut Self
highres fix target width, 0 to use scale (default: 0)
Sourcepub fn upscale_tile_size(&mut self, value: i32) -> &mut Self
pub fn upscale_tile_size(&mut self, value: i32) -> &mut Self
highres fix upscaler tile size, reserved for model-backed upscalers (default: 128)
Sourcepub fn scale(&mut self, value: f32) -> &mut Self
pub fn scale(&mut self, value: f32) -> &mut Self
highres fix scale when sizes is not set (default: 2.0)
Sourcepub fn denoising_strength(&mut self, value: f32) -> &mut Self
pub fn denoising_strength(&mut self, value: f32) -> &mut Self
highres fix second pass denoising strength (default: 0.7)
Sourcepub fn hires_sigmas(&mut self, value: Option<Vec<f32>>) -> &mut Self
pub fn hires_sigmas(&mut self, value: Option<Vec<f32>>) -> &mut Self
Custom sigma values for the highres fix second pass
Sourcepub fn build(&self) -> Result<HiresParams, HiresParamsBuilderError>
pub fn build(&self) -> Result<HiresParams, HiresParamsBuilderError>