Safer wrapper around stable-diffusion.cpp bindings
Structs
- Backend
Device Iter - An iterator over the variants of BackendDevice
- Config
- Config struct common to all diffusion methods
- Config
Builder - Builder for
Config. - DbCache
Params - Parameters for Db Cache
- DbCache
Params Builder - Builder for
DbCacheParams. - Easy
Cache Params - Parameters for Easy Cache
- Easy
Cache Params Builder - Builder for
EasyCacheParams. - Hires
Params - Hires parameters
- Hires
Params Builder - Builder for
HiresParams. - Lora
Spec - Specify the instructions for a Lora model
- Model
Config - Config struct for a specific diffusion model
- Model
Config Builder - Builder for
ModelConfig. - Module
Iter - An iterator over the variants of Module
- Progress
- Progress message returned fron gen_img_with_progress
- Spectrum
Cache Params - Parameters for Spectrum Caching
- Spectrum
Cache Params Builder - Builder for
SpectrumCacheParams. - UCache
Params - Parameters for UCache
- UCache
Params Builder - Builder for
UCacheParams.
Enums
- Backend
Device - Backend devices
- Clip
Skip - Ignore the lower X layers of CLIP network
- Config
Builder Error - Error type for ConfigBuilder
- DbCache
Params Builder Error - Error type for DbCacheParamsBuilder
- Diffusion
Error - Error that can occurs while forwarding models
- Easy
Cache Params Builder Error - Error type for EasyCacheParamsBuilder
- Hires
Params Builder Error - Error type for HiresParamsBuilder
- Lora
Mode Type - Lora mode
- Module
- Module that can be bound to a specific BackendDevice
- Prediction
- Prediction override
- Preview
Type - Preview mode
- RngFunction
- Specify the range function
- Sample
Method - Sampling methods
- Scheduler
- Denoiser sigma schedule
- ScmPolicy
- Steps Computation Mask Policy controls when to cache steps
- Spectrum
Cache Params Builder Error - Error type for SpectrumCacheParamsBuilder
- UCache
Params Builder Error - Error type for UCacheParamsBuilder
- Upscaler
- Hires mode
- VaeFormat
- VAE latent format
- Weight
Type - Weight type
Functions
- gen_img
- Generate an image
- gen_
img_ with_ progress - Generate an image and receive update via queue